@@ -2,6 +2,7 @@ import SimpleITK as sitk
 import matplotlib.pyplot as plt
 from medimtools.viz.ops import *
 
+
 def quick_view(
     image: sitk.Image,
     display: bool = True,
@@ -9,10 +10,11 @@ def quick_view(
     cmap: str = "gray",
     mask=None,
     contour=None,
+    coords=None,
 ):
 
     if int(image.GetPixelID()) != 1:
-        logger.info("Rescaling image ...")
+        logger.info("Rescaling image for vizualization ...")
         # [0,255] for visualization purposes
         image = sitk.Cast(sitk.RescaleIntensity(image, 0, 255), sitk.sitkUInt8)
 
@@ -25,16 +27,20 @@ def quick_view(
         if contour:
             contour = make_isotropic(contour, interpolator=sitk.sitkNearestNeighbor)
 
-    if mask:
-        image = overlay_mask(image, mask)
-
     if contour:
-        image = overlay_mask(image, contour, contour=True)
+        mask = get_contour(contour)
 
-    image = get_image_preview(image)
+    image = get_image_preview(image, coords=coords)
+
+    if mask:
+        mask = get_image_preview(mask, coords=coords)
 
     if display:
         plt.imshow(image, cmap=cmap)
+
+        if mask is not None:
+            plt.imshow(mask, cmap=cmap, alpha=0.5)
+
         plt.show()
 
     return image
